@@ -20,6 +20,7 @@
 #include <QWidget>
 #include <QString>
 #include <QMessageBox>
+#include <QSqlQuery>
 #include "contact.h"
 
 #define QUOTE_(x) #x
@@ -30,11 +31,11 @@ class CommonStatic
 public:
     static QList<Contact*> ContactsCache;
     static QHash<int, Contact*> ContactsCacheIds;
-    static QHash<QString, int> ContactsCacheNumbers;
+    static QHash<QString, Contact*> ContactsCacheNumbers;
 
     static void LoadContactsCache();
     static Contact* GetContact(int id);
-    static bool ContactExists(QString number);
+    static Contact* GetContact(QString number);
 
     static QMessageBox::StandardButton ConfirmMessage(QWidget* parent, QString title, QString message);
     static void ErrorMessage(QWidget* parent, QString message);
@@ -44,6 +45,8 @@ public:
     static QString GetSettingsFolder();
 
     static bool IsMouseOver(QWidget* w);
+
+    static bool ExecuteQuery(QString sql, QSqlQuery* query = 0);
 };
 
 #endif // COMMONSTATIC_H
