@@ -20,10 +20,14 @@
 Contact::Contact()
 {
     Thumbnail = NULL;
+    eMails = NULL;
+    Selected = false;
 }
 
 Contact::~Contact()
 {
     if (Thumbnail != NULL)
         delete Thumbnail;
+    if (eMails != NULL)
+        delete eMails;
 }
