@@ -19,18 +19,19 @@
 #define CONTACT_H
 
 #include <QImage>
-
+#include <QStringList>
 class Contact
 {
 public:
     explicit Contact();
     ~Contact();
 
+    bool Selected;
     QImage* Thumbnail;
     int Id;
     QString Name;
     QString Number;
-    QString eMail;
+    QStringList* eMails;
 };
 
 #endif // CONTACT_H
