@@ -24,7 +24,7 @@
 
 bool toAscending(const Contact* s1 , const Contact* s2)
 {
-    return s1->Name < s2->Name;
+    return QString::compare(s1->Name, s2->Name, Qt::CaseInsensitive) < 0;
 }
 
 void ContactsLoader::run()
@@ -61,21 +61,31 @@ void ContactsLoader::run()
     numbers->clear();
     if (!contacts.isEmpty()){
         foreach (QContact c, contacts){
-            QStringList cNumbers;
-            if (IsContactValid(&c, &cNumbers)) {
-                foreach (QString number, cNumbers){
+            if (!c.isEmpty() && c.type() == QContactType::TypeContact){
+                QStringList* cEmails = new QStringList();
+                QList<QContactDetail> emails = c.details(QContactEmailAddress::DefinitionName);
+                foreach (QContactDetail detail, emails){
+                    QContactEmailAddress* eml = (QContactEmailAddress*)(&detail);
+                    cEmails->append(eml->emailAddress());
+                }
+
+                QList<QContactDetail> phns = c.details(QContactPhoneNumber::DefinitionName);
+                foreach (QContactDetail detail, phns){
+                    QContactPhoneNumber* phn = (QContactPhoneNumber*)(&detail);
+                    QString number = phn->number();
                     if (!numbers->contains(number)){
                         numbers->append(number);
                         Contact* contact = new Contact();
                         contact->Id = c.localId();
                         contact->Name = c.displayLabel();
                         contact->Number = number;
+                        contact->eMails = cEmails;
 
                         QContactThumbnail thn = c.detail(QContactThumbnail::DefinitionName);
                         if (!thn.isEmpty())
                             contact->Thumbnail = new QImage(thn.thumbnail().scaled(48, 48, Qt::KeepAspectRatio));
                         CommonStatic::ContactsCache.append(contact);
-                        CommonStatic::ContactsCacheNumbers[contact->Number] = contact->Id;
+                        CommonStatic::ContactsCacheNumbers[contact->Number] = contact;
                         CommonStatic::ContactsCacheIds[contact->Id] = contact;
                     }
                 }
@@ -103,7 +113,7 @@ void ContactsLoader::run()
         contact->Number = contacts->value("number").toString();
 
         CommonStatic::ContactsCache.append(contact);
-        CommonStatic::ContactsCacheNumbers[contact->Number] = contact->Id;
+        CommonStatic::ContactsCacheNumbers[contact->Number] = contact;
         CommonStatic::ContactsCacheIds[contact->Id] = contact;
     }
 
@@ -115,19 +125,3 @@ void ContactsLoader::run()
     delete numbers;
     qSort(CommonStatic::ContactsCache.begin() , CommonStatic::ContactsCache.end(), toAscending );
 }
-
-#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
-bool ContactsLoader::IsContactValid(QContact* c, QStringList* numbers)
-{
-    numbers->clear();
-    if (!c->isEmpty() && c->type() == QContactType::TypeContact){
-        QList<QContactDetail> phns = c->details(QContactPhoneNumber::DefinitionName);
-        foreach (QContactDetail detail, phns){
-            QContactPhoneNumber* phn = (QContactPhoneNumber*)(&detail);
-            numbers->append(phn->number());
-        }
-        return true;
-    }
-    return false;
-}
-#endif
