@@ -34,6 +34,8 @@ bool Group::IsValid()
 
 bool Group::SaveToDb()
 {
+    CommonStatic::ExecuteQuery("BEGIN TRANSACTION");
+
     QString query;
     if (!IsValid()){
         query = QString("Insert into groups (g_name) values('%1')").arg(Name);
@@ -42,26 +44,21 @@ bool Group::SaveToDb()
     }
 
     QSqlQuery qry;
-    if (!qry.prepare(query))
-        return false;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return false;
 
     query = QString("delete from group_contacts where gc_group_id=%1").arg(Id);
-    if (!qry.prepare(query))
-        return false;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return false;
 
     foreach(GroupContact* c, ContactsId){
         query = QString("insert into group_contacts (gc_group_id, gc_contact_id, gc_number) \
                          values(%1, %2, '%3')").arg(Id).arg(c->Id).arg(c->Number);
-        QSqlQuery qry;
-        if (!qry.prepare(query))
-            return false;
-        if (!qry.exec())
+        if (!CommonStatic::ExecuteQuery(query, &qry))
             return false;
     }
+
+    CommonStatic::ExecuteQuery("COMMIT");
     return true;
 }
 
@@ -73,9 +70,7 @@ bool Group::LoadFromDb()
     QString query = QString("Select g_id, g_name from groups where g_id=%1").arg(Id);
     QSqlQuery qry;
     QSqlRecord rec;
-    if (!qry.prepare(query))
-        return false;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return false;
 
     qry.next();    
@@ -86,9 +81,7 @@ bool Group::LoadFromDb()
     }
 
     query = QString("Select gc_contact_id, gc_number from group_contacts where gc_group_id=%1").arg(Id);
-    if (!qry.prepare(query))
-        return false;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return false;
     while(qry.next()){
         rec = qry.record();
@@ -106,9 +99,7 @@ bool Group::Exists(QString Name)
 {
     QString query = QString("Select 1 from groups where g_name='%1'").arg(Name);
     QSqlQuery qry;
-    if (!qry.prepare(query))
-        return false;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return false;
 
     qry.next();
@@ -123,9 +114,7 @@ QList<Group*> Group::GetGroupList()
 
     QString query = QString("Select g_id from groups order by g_name");
     QSqlQuery qry;
-    if (!qry.prepare(query))
-        return res;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return res;
 
     QSqlRecord rec;
@@ -171,15 +160,11 @@ bool Group::Delete()
 
     QString query = QString("Delete from groups where g_id=%1").arg(Id);
     QSqlQuery qry;
-    if (!qry.prepare(query))
-        return false;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return false;
 
     query = QString("Delete from group_contacts where gc_group_id=%1").arg(Id);
-    if (!qry.prepare(query))
-        return false;
-    if (!qry.exec())
+    if (!CommonStatic::ExecuteQuery(query, &qry))
         return false;
     return true;
 }
@@ -189,8 +174,11 @@ int Group::RemoveInvalidNumbers()
     QList<GroupContact*> toRemove;
 
     foreach (GroupContact* gc, ContactsId){
-        if (!CommonStatic::ContactExists(gc->Number))
+        Contact* c = CommonStatic::GetContact(gc->Number);
+        if (c == NULL)
             toRemove.append(gc);
+        else
+            gc->Id = c->Id;
     }
 
     foreach (GroupContact* gc, toRemove){
