@@ -22,10 +22,7 @@
 #include "contactswindow.h"
 #include "editgroupwindow.h"
 #include "commonstatic.h"
-
-#ifdef Q_WS_MAEMO_5
-#include "hildon-uri.h"
-#endif
+#include "sendwindow.h"
 
 GroupActionsWindow::GroupActionsWindow(QWidget *parent, Group* group) :
     QDialog(parent),
@@ -54,15 +51,15 @@ GroupActionsWindow::GroupActionsWindow(QWidget *parent, Group* group) :
 
     ui->tblContacts->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui->tblContacts, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(ContactMenuSlot(QPoint)));
-    connect(ui->tblContacts, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(ContactDoubleClick(int, int)));
+    connect(ui->tblContacts, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(ContactDoubleClick(QModelIndex)));
     connect(ui->btnAdd, SIGNAL(clicked()), this, SLOT(AddContactSlot()));
     connect(ui->btnRemove, SIGNAL(clicked()), this, SLOT(RemoveSlot()));
     connect(ui->btnSendSMS, SIGNAL(clicked()), this, SLOT(SendSlot()));
     connect(ui->btnEdit, SIGNAL(clicked()), this, SLOT(EditSlot()));
 
-    ui->tblContacts->setColumnCount(4);
     ui->tblContacts->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 
+    m_DataModel = NULL;
     PopulateContactsTable();
     SelectAllContacts();
 
@@ -72,51 +69,36 @@ GroupActionsWindow::GroupActionsWindow(QWidget *parent, Group* group) :
 GroupActionsWindow::~GroupActionsWindow()
 {
     delete ui;
+    if (m_DataModel){
+        delete m_DataModel;
+        m_DataModel = NULL;
+    }
 }
 
 
+bool sortByName(const Contact* s1 , const Contact* s2)
+{
+    return QString::compare(s1->Name, s2->Name, Qt::CaseInsensitive) < 0;
+}
+
 void GroupActionsWindow::PopulateContactsTable()
 {    
-    ui->tblContacts->setSortingEnabled(false);
-    ui->tblContacts->setRowCount(m_Group->ContactsId.count());
-
-    int i = 0;
-    QPixmap defaultImage = (new QPixmap(":/images/contacts.png"))->scaled(48, 48, Qt::KeepAspectRatio);
-    QTableWidgetItem* item;
-    foreach(GroupContact* gc, m_Group->ContactsId){
-        Contact* c = CommonStatic::GetContact(gc->Id);
-        if (c){
-            ui->tblContacts->setRowHeight(i, 60);
-            QCheckBox* chk = new QCheckBox(ui->tblContacts);
-            chk->setStyleSheet("border-style: none;");
-            chk->setText("");
-            chk->setObjectName(QString("%1").arg(c->Id));
-            ui->tblContacts->setCellWidget(i, 0, chk);            
-
-            QLabel* lbl = new QLabel(ui->tblContacts);
-            lbl->setAlignment(Qt::AlignCenter);
-            lbl->setMaximumWidth(48);
-            if (c->Thumbnail != NULL)
-                lbl->setPixmap(QPixmap::fromImage(*c->Thumbnail));
-            else{
-                lbl->setPixmap(defaultImage);
-            }
-            ui->tblContacts->setCellWidget(i, 1, lbl);
-
-            item = new QTableWidgetItem(0);
-            item->setText(c->Name);
-            ui->tblContacts->setItem(i, 2, item);
-
-            item = new QTableWidgetItem(0);
-            item->setText(gc->Number);
-            ui->tblContacts->setItem(i, 3, item);
-
-            i++;
-        }
+    if (m_DataModel){
+        delete m_DataModel;
+        m_DataModel = NULL;
     }
 
-    ui->tblContacts->sortItems(2, Qt::AscendingOrder);
-    ui->tblContacts->setSortingEnabled(true);    
+    foreach(GroupContact* gc, m_Group->ContactsId){
+        Contact* c = CommonStatic::GetContact(gc->Number);
+        if (c)
+            m_Contacts.append(c);
+    }
+    qSort(m_Contacts.begin() , m_Contacts.end(), sortByName );
+
+    m_DataModel = new ContactsDataModel(this, &m_Contacts);
+    ui->tblContacts->setModel(m_DataModel);
+    ui->tblContacts->verticalHeader()->setDefaultSectionSize(60);
+    ui->tblContacts->verticalHeader()->setDefaultAlignment(Qt::AlignVCenter | Qt::AlignLeft);
     ui->tblContacts->resizeColumnToContents(0);
     ui->tblContacts->resizeColumnToContents(1);
 }
@@ -160,43 +142,25 @@ void GroupActionsWindow::RemoveSlot()
 
 void GroupActionsWindow::SendSlot()
 {
-    QList<QString> toSend = GetSelectedNumbers();
-    if (toSend.count() > 0){
-#ifdef Q_WS_MAEMO_5
-            QString strTo;
-            foreach (QString n, toSend){
-                if (!strTo.isEmpty())
-                    strTo.append(", ");
-                strTo.append(n);
-            }
-
-            QUrl smsUrl((QString("sms:%1").arg(strTo)));
-            smsUrl.addQueryItem("body", "");
-            hildon_uri_open(smsUrl.toString().toStdString().c_str(),NULL,NULL);
-#endif
-        //}
+    QList<Contact*> contacts = m_DataModel->getSelected();
+    if (contacts.count()){
+        SendWindow* frm = new SendWindow(this, &contacts);
+        frm->exec();
+        delete frm;
     }
 }
 
 QList<QString> GroupActionsWindow::GetSelectedNumbers()
 {
     QList<QString> res;
-    for (int i=0; i<ui->tblContacts->rowCount(); i++){
-        QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(i, 0);
-        if (chk->isChecked()){
-            QTableWidgetItem* lbl = (QTableWidgetItem*)ui->tblContacts->item(i, 3);
-            res.append(lbl->text());
-        }
-    }
+    foreach (Contact* c, m_DataModel->getSelected())
+        res.append(c->Number);
     return res;
 }
 
 void GroupActionsWindow::SelectAllContacts(bool select)
 {
-    for (int i=0; i<ui->tblContacts->rowCount(); i++){
-        QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(i, 0);
-        chk->setChecked(select);
-    }
+    m_DataModel->selectAll(select);
 }
 
 void GroupActionsWindow::EditSlot()
@@ -224,10 +188,9 @@ void GroupActionsWindow::resizeEvent (QResizeEvent*)
     ui->tblContacts->setColumnWidth(3, w / 2);
 }
 
-void GroupActionsWindow::ContactDoubleClick(int row, int)
+void GroupActionsWindow::ContactDoubleClick(QModelIndex index)
 {
-    QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(row, 0);
-    chk->setChecked(!chk->isChecked());
+    m_DataModel->toggleSelect(index);
 }
 
 
@@ -252,12 +215,9 @@ void GroupActionsWindow::RemoveOneSlot()
                                      tr("Confirm remove"),
                                      QString(tr("Remove 1 contact from group %1?"))
                                      .arg(m_Group->Name)) == QMessageBox::Yes){
-        QTableWidgetItem* lbl = (QTableWidgetItem*)ui->tblContacts->item(ui->tblContacts->currentRow(), 3);
-        if (lbl != NULL){
-            m_Group->Remove(lbl->text());
-            m_Group->SaveToDb();
-            PopulateContactsTable();
-            SelectAllContacts();
-        }
+        m_Group->Remove(m_DataModel->getContact(ui->tblContacts->currentIndex())->Number);
+        m_Group->SaveToDb();
+        PopulateContactsTable();
+        SelectAllContacts();
     }
 }
