@@ -17,6 +17,7 @@
 //    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <QtGui/QApplication>
 #include <QDir>
+#include <QTranslator>
 #include "mainwindow.h"
 #include "commonstatic.h"
 
@@ -25,6 +26,12 @@ int main(int argc, char *argv[])
     QApplication a(argc, argv);
     a.setApplicationVersion(QUOTE(APP_VERSION));
 
+    QString locale = QLocale::system().name();
+    QTranslator translator;
+    QString path = QApplication::applicationDirPath();
+    if (translator.load(QString("%1/groupsms_%2").arg(path).arg(locale)))
+        a.installTranslator(&translator);
+
     QString folder = CommonStatic::GetSettingsFolder();
     if (!QDir().exists(folder))
         QDir().mkdir(folder);
