@@ -26,6 +26,7 @@
 #include <QTimer>
 #ifdef Q_WS_MAEMO_5
 #include "hildon-uri.h"
+#include <QUrl>
 #endif
 #include "commonstatic.h"
 #include "editgroupwindow.h"
@@ -91,8 +92,7 @@ void MainWindow::OpenDB()
         m_Db = NULL;
     }else{        
         QSqlQuery qry;
-        if (qry.prepare("PRAGMA synchronous=OFF;"))
-            qry.exec();
+        CommonStatic::ExecuteQuery("PRAGMA synchronous=OFF;", &qry);
         CreateTables();
     }
 }
@@ -117,9 +117,7 @@ bool MainWindow::CreateTables()
 
     QSqlQuery qry;
     foreach(QString query, queries){
-        if (!qry.prepare(query))
-            return false;
-        if (!qry.exec())
+        if (!CommonStatic::ExecuteQuery(query, &qry))
             return false;
     }
     return true;
